from . import download, download_playlist
def mp4(): download(input("https://www.youtube.com/watch?v="), outname='out.mp4')
def webm(): download(input("https://www.youtube.com/watch?v="), outname='out.webm')
def mkv(): download(input("https://www.youtube.com/watch?v="), outname='out.mkv')
def flv(): download(input("https://www.youtube.com/watch?v="), outname='out.flv')
def wmv(): download(input("https://www.youtube.com/watch?v="), outname='out.wmv')
def avi(): download(input("https://www.youtube.com/watch?v="), outname='out.avi')
def mov(): download(input("https://www.youtube.com/watch?v="), outname='out.mov')
def m4v(): download(input("https://www.youtube.com/watch?v="), outname='out.m4v')
def mp3(): download(input("https://www.youtube.com/watch?v="), outname='out.mp3')
def pmp4(): download_playlist(input("https://www.youtube.com/playlist?list="), input("API key: "), "mp4")
def pwebm(): download_playlist(input("https://www.youtube.com/playlist?list="), input("API key: "), "webm")
def pmkv(): download_playlist(input("https://www.youtube.com/playlist?list="), input("API key: "), "mkv")
def pflv(): download_playlist(input("https://www.youtube.com/playlist?list="), input("API key: "), "flv")
def pwmv(): download_playlist(input("https://www.youtube.com/playlist?list="), input("API key: "), "wmv")
def pavi(): download_playlist(input("https://www.youtube.com/playlist?list="), input("API key: "), "avi")
def pmov(): download_playlist(input("https://www.youtube.com/playlist?list="), input("API key: "), "mov")
def pm4v(): download_playlist(input("https://www.youtube.com/playlist?list="), input("API key: "), "m4v")
def pmp3(): download_playlist(input("https://www.youtube.com/playlist?list="), input("API key: "), "mp3")
if __name__ == '__main__': mp4()



from json import loads
from urllib.request import urlopen
from seleniumwire.webdriver import Firefox
from selenium.webdriver.firefox.webdriver import Options
from moviepy.editor import VideoFileClip, AudioFileClip
firefox_options = Options()
firefox_options.headless = True
def download(id, outname='output.mp4', fps=60):
    driver = Firefox(options=firefox_options) # needed
    driver.get('https://www.youtube.com/watch?v=%s' % id.replace('https://', '').replace('www.', '').replace('music.', '').replace('youtube.com/watch?v=', '').replace('youtu.be/', ''))
    vid, aud = list(map(lambda url: '&'.join(filter(lambda element: 'range' not in element, url.split('&'))), filter(lambda req: '---' in req and 'generate' not in req, map(lambda req: req.url, driver.requests))))[:2]
    driver.quit()
    if outname.endswith('.mp4'):
        VideoFileClip(vid).set_audio(AudioFileClip(aud)).write_videofile(outname,fps=fps)
    elif outname.endswith('.webm'):
        VideoFileClip(vid).set_audio(AudioFileClip(aud)).write_videofile(outname,fps=fps,codec='libvpx-vp9')
    elif outname.endswith('.mkv'):
        VideoFileClip(vid).set_audio(AudioFileClip(aud)).write_videofile(outname,fps=fps,codec='libx264')
    elif outname.endswith('.flv'):
        VideoFileClip(vid).set_audio(AudioFileClip(aud)).write_videofile(outname,fps=fps,codec='flv')
    elif outname.endswith('.wmv'):
        VideoFileClip(vid).set_audio(AudioFileClip(aud)).write_videofile(outname,fps=fps,codec='wmv2')
    elif outname.endswith('.avi') or outname.endswith('.mov') or outname.endswith('.m4v'):
        VideoFileClip(vid).set_audio(AudioFileClip(aud)).write_videofile(outname,fps=fps,codec='mpeg4')
    elif outname.endswith('.mp3'):
        AudioFileClip(aud).write_audiofile(outname)
    else:
        raise Exception('Unknown file extension')
def download_playlist(id, api_key, extension='mp4', fps=60):
    for video, name in map(lambda data: (data["snippet"]["resourceId"]["videoId"], data["snippet"]["title"]), loads(urlopen("https://www.googleapis.com/youtube/v3/playlistItems?playlistId=%s&part=snippet&maxResults=50&key=%s" % (id[id.find("list=") + 5 if id.find("list=") > 0 else 0:], api_key)).read())["items"]): download(video, name + "." + extension, fps=fps)



from setuptools import setup, find_packages
setup(
    name='yt2mp4',
    version='1.0.3',
    license='MIT',
    author='Elisha Hollander',
    author_email='just4now666666@gmail.com',
    description='Download YouTube videos and playlists as MP4 files (and other formats)',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    url='https://github.com/donno2048/yt2mp4',
    project_urls={
        'Documentation': 'https://github.com/donno2048/yt2mp4#readme',
        'Bug Reports': 'https://github.com/donno2048/yt2mp4/issues',
        'Source Code': 'https://github.com/donno2048/yt2mp4',
    },
    python_requires='>=3.0',
    packages=find_packages(),
    install_requires=['selenium==4.1.0', 'selenium-wire==4.5.6', 'moviepy==1.0.3'],
    classifiers=['Programming Language :: Python :: 3'],
    entry_points={ 'console_scripts': [
        'yt2mp4=yt2mp4.__main__:mp4',
        'yt2webm=yt2mp4.__main__:webm',
        'yt2mkv=yt2mp4.__main__:mkv',
        'yt2flv=yt2mp4.__main__:flv',
        'yt2wmv=yt2mp4.__main__:wmv',
        'yt2avi=yt2mp4.__main__:avi',
        'yt2movie=yt2mp4.__main__:mov',
        'yt2m4v=yt2mp4.__main__:m4v',
        'yt2mp3=yt2mp4.__main__:mp3',
        'ytp2mp4=yt2mp4.__main__:pmp4',
        'ytp2webm=yt2mp4.__main__:pwebm',
        'ytp2mkv=yt2mp4.__main__:pmkv',
        'ytp2flv=yt2mp4.__main__:pflv',
        'ytp2wmv=yt2mp4.__main__:pwmv',
        'ytp2avi=yt2mp4.__main__:pavi',
        'ytp2movie=yt2mp4.__main__:pmov',
        'ytp2m4v=yt2mp4.__main__:pm4v',
        'ytp2mp3=yt2mp4.__main__:pmp3'
    ] }
)
